@@ -189,6 +189,33 @@ def inspect(ctx, is_raw):
         return
 
 
+@job.command(help="Display estimated cost of the job")
+@option('--recalculate', 'recalculate', is_flag=True, help="Recalculate the cost for the Job")
+@option('--raw', 'is_raw', is_flag=True, help='Dump raw json response from endpoint')
+@pass_context
+def cost(ctx, recalculate, is_raw):
+    workflow_job = ctx.obj.job
+    cost_detail = workflow_job.cost(recalculate)
+    if cost_detail:
+        if is_raw:
+            echo(dumps(cost_detail))
+            return
+
+        print_tab("cost", f"{cost_detail['cost']:.2f} {cost_detail['currency']}")
+        cad = datetime.datetime.strptime(cost_detail["calculation_date"], '%Y-%m-%dT%H:%M:%S.%f')
+        print_tab("calculated_at", cad.strftime('%Y-%m-%d %H:%M:%S'))
+        print_tab("cost_model", cost_detail["cost_model"])
+        print_tab("MODEL DETAILS", "")
+        print_tab("lines_ok", cost_detail["details"]["lines"]["processed"])
+        print_tab("lines_bad", cost_detail["details"]["lines"]["bad"])
+        print_tab("lines_skipped", cost_detail["details"]["lines"]["skipped"])
+        print_tab("full_price", cost_detail["details"]["price"]["full_price"])
+        print_tab("total_price", cost_detail["details"]["price"]["total_price"])
+
+    else:
+        print_error(f"Could not get cost for job {workflow_job.job_id}")
+
+
 @job.command(help="View information about the job")
 @option('--raw', 'is_raw', is_flag=True, help='Dump raw json response from endpoint')
 @pass_context
@@ -212,6 +239,10 @@ def view(ctx, is_raw):
     if workflow_job.complete_date:
         print_tab('completed', complete_date.strftime('%Y-%m-%d %H:%M:%S'))
     print_tab('duration', str(complete_date - submit_date).split('.')[0])
+    cost = "<Cost hasn't been calculated for this job>"
+    if workflow_job.cost_amount:
+        cost = f"{workflow_job.cost_amount:.2f} {workflow_job.cost_currency}"
+    print_tab('cost', cost)
     print_tab('context', getattr(workflow_job, 'context', ''))
 
     print_tab('nextflow ID', workflow_job.run_id)
